==> feedify-3.0.1.tar.gz: README.md <==
Speak directly to your subscribers one on one with personalized, targeted and result oriented Push Notifications.


## Features
### Choose
- Create something interesting and actionable with Feedify. Add images, icons, emojis, action buttons
and an interesting crisp text that pops and shines on the subscriber’s device.
Read more at [Feedify.net](https://feedify.net/mobile-push-notifications).

### Campaign
- Initiate a Drip Notifications Campaign and automate an engagement for every new visitor that comes to your site.
   Pour in a pre-defined stream of Notification at regular intervals and kick-start real time engagement.
Read more at [Feedify.net](https://feedify.net/mobile-push-notifications).

### Count
- Keep a track of your performance with rich analytics that measure user interaction.
Read more at [Feedify.net](https://feedify.net/mobile-push-notifications).

## Getting started (Android)

Installation is very straightforward, you need to add app in your firebase console. You can follow
this guide [Firebase Setup](https://firebase.google.com/docs/android/setup). Just download
google-services.json.

Now copy this google-services.json into your root of app assets directory this is important step.

Now in order to enable Firebase services in our Android app, we need to add the google-services plugin to our Gradle files.

First in our root-level (project-level) Gradle file (android/build.gradle), we need to add rules to
include the Google Services Gradle plugin. We need to check if the following configurations are available or not:

        buildscript {
            ext.kotlin_version = '1.5.21'
            repositories {
                google()
                mavenCentral()
            }

            dependencies {
                classpath 'com.android.tools.build:gradle:4.1.0'
                classpath "org.jetbrains.kotlin:kotlin-gradle-plugin:$kotlin_version"
                classpath 'com.google.gms:google-services:4.3.10'
            }
        }

        allprojects {
            repositories {
                google()
                mavenCentral()
            }
        }

        rootProject.buildDir = '../build'
        subprojects {
            project.buildDir = "${rootProject.buildDir}/${project.name}"
        }
        subprojects {
            project.evaluationDependsOn(':app')
        }

        task clean(type: Delete) {
            delete rootProject.buildDir
        }


Now in our module (app-level) Gradle file (android/app/build.gradle), we need to apply the Google Services Gradle plugin.
For that, we need to add the piece of code highlighted in the following code snippet to the
./android/app/build.gradle file of our project:

        apply plugin: 'com.google.gms.google-services'

        dependencies {
            implementation "org.jetbrains.kotlin:kotlin-stdlib-jdk7:$kotlin_version"
            implementation platform('com.google.firebase:firebase-bom:29.0.0')
            implementation 'com.google.firebase:firebase-analytics-ktx'
        }

Now, we need to run the following command so that some automatic configurations can be made:

        flutter pub get


Using Feedify you can also send http/ https URLs into the notifications hence to support them android has now
introduced to add query parameters into your AndroidManifest.xml like below:

        <queries>
                <!-- If your app opens https URLs -->
                <intent>
                    <action android:name="android.intent.action.VIEW" />
                    <data android:scheme="https" />
                </intent>
                <intent>
                    <action android:name="android.intent.action.VIEW" />
                    <data android:scheme="http" />
                </intent>
            </queries>

You can read more at android developer's [site](https://developer.android.com/guide/topics/manifest/queries-element)

## Usage (common for Android and iOS)

        void main() async {
          initFeedSDK();
          runApp(const MyApp());
        }

        void initFeedSDK() async {
          WidgetsFlutterBinding.ensureInitialized();
          var sdk = FeedSDK.getInstance(
              feedifyKey: 'key',
              feedifyDomain: 'domain',
              feedifyUser: 'userKey');
          // if you want to show your own custom icon instead of Feedify's own icon
          FeedSDK.setNotificationIcon('resource://drawable/ic_notification');
          // If FeedSDK.startScreen is set then all the notification payload data is passed to the startScreen
          FeedSDK.startScreen = 'test';
          Logs.setEnabled(true);
          await sdk.init(
              appName: 'your app name',
              projectId: 'firebase project Id',
              firebaseCurrentApiKey: 'firebase api key',
              firebaseMobileSdkAppId: 'firebase mobile app sdk id',
              firebaseStorageBucket: 'firebase storage key url',
              firebaseUrl: '',
              firebaseProjectNumber: 'firebase project number');
        }

- Note: All the above information can be found in google-services.json and info.plist file that has
  been already downloaded from Google firebase console.

If you have set FeedSDK.startScreen and want to override the SDK's default behaviour by receiving
all the data payload to the main app class, then you need to do add the below package into your
pubspec.yaml file (don't forget to call - 'flutter pub get')

        get: ^4.3.7

then add the GetMaterialApp widget as below sample:

        class MyApp extends StatelessWidget {
          const MyApp({Key? key}) : super(key: key);

          // This widget is the root of your application.
          @override
          Widget build(BuildContext context) {
            return GetMaterialApp(
              onGenerateRoute: (settings) {
                if (settings.name == FeedSDK.startScreen) {
                  final args = settings.arguments;
                  Logs.d('onGenerateRoute $args');
                }
              },
              title: 'Flutter Demo',
              theme: ThemeData(
                primarySwatch: Colors.blue,
              ),
              home: const MyHomePage(title: 'Flutter Demo Home Page'),
            );
          }
        }

You can read the data based on the keys available inside Constants class.

## Getting started (iOS)

Integrating the Cloud Messaging plugin on iOS & macOS devices requires additional setup before your
devices receive messages. There are also a number of prerequisites which are required to be able to
enable messaging:

- You must have an active
  Apple [Developer Account](https://idmsa.apple.com/IDMSWebAuth/signin?appIdKey=891bd3417a7776362562d2197f89480a8547b108fd934911bcbea0110d07f757&path=%2Faccount%2F&rv=1)
  .
- For iOS; you must have a physical iOS device to receive messages.
    - Firebase Cloud Messaging integrates with
      the [Apple Push Notification service (APNs)](https://developer.apple.com/notifications/),
      however APNs only works with real devices.

For configuring FCM on iOS devices, follow
the [steps mentioned in here](https://firebase.flutter.dev/docs/messaging/apple-integration/#configuring-your-app)

The most important part in order to make this library
work [is](https://firebase.flutter.dev/docs/messaging/apple-integration/#linking-apns-with-fcm)

==> feedify-3.0.2.tar.gz: README.md <==
## Getting started (Android)

Add app in your firebase console. You can follow this
guide [Firebase Setup](https://firebase.google.com/docs/android/setup). Just download
google-services.json.

Copy google-services.json into your root of app assets directory this is important step.

Now in order to enable Firebase services in our Android app, add the google-services plugin to our
Gradle files.

First in our root-level (project-level) Gradle file (android/build.gradle), add rules to include the
Google Services Gradle plugin.

Check if the following configurations are available or not:

        buildscript {
            ext.kotlin_version = '1.5.21'
            repositories {
                google()
                mavenCentral()
            }

            dependencies {
                classpath 'com.android.tools.build:gradle:4.1.0'
                classpath "org.jetbrains.kotlin:kotlin-gradle-plugin:$kotlin_version"
                classpath 'com.google.gms:google-services:4.3.10'
            }
        }

        allprojects {
            repositories {
                google()
                mavenCentral()
            }
        }

        rootProject.buildDir = '../build'
        subprojects {
            project.buildDir = "${rootProject.buildDir}/${project.name}"
        }
        subprojects {
            project.evaluationDependsOn(':app')
        }

        task clean(type: Delete) {
            delete rootProject.buildDir
        }

Now in our module (app-level) Gradle file (android/app/build.gradle), apply the Google Services
Gradle plugin. For that, add the piece of code highlighted in the following code snippet to the
./android/app/build.gradle file of our project:

        apply plugin: 'com.google.gms.google-services'

        dependencies {
            implementation "org.jetbrains.kotlin:kotlin-stdlib-jdk7:$kotlin_version"
            implementation platform('com.google.firebase:firebase-bom:29.0.0')
            implementation 'com.google.firebase:firebase-analytics-ktx'
        }

Now, run the following command so that some automatic configurations can be made:

        flutter pub get

Using Feedify you can also send http/ https URLs into the notifications hence to support them
android has now introduced to add query parameters into your AndroidManifest.xml like below:

        <queries>
                <!-- If your app opens https URLs -->
                <intent>
                    <action android:name="android.intent.action.VIEW" />
                    <data android:scheme="https" />
                </intent>
                <intent>
                    <action android:name="android.intent.action.VIEW" />
                    <data android:scheme="http" />
                </intent>
            </queries>

You can read more at android
developer's [site](https://developer.android.com/guide/topics/manifest/queries-element)

## Usage (common for Android and iOS)

        void main() async {
          initFeedSDK();
          runApp(const MyApp());
        }

        void initFeedSDK() async {
          WidgetsFlutterBinding.ensureInitialized();
          var sdk = FeedSDK.getInstance(
              feedifyKey: 'key',
              feedifyDomain: 'domain',
              feedifyUser: 'userKey');
          // mandatory to set the notification icon, else notification alert will not show
          FeedSDK.setNotificationIcon('resource://drawable/ic_notification');
          // If FeedSDK.startScreen is set then all the notification payload data is passed to the root widget of your app
          FeedSDK.startScreen = 'test';
          Logs.setEnabled(true);
          await sdk.init(
              appName: 'your app name',
              projectId: 'firebase project Id',
              firebaseCurrentApiKey: 'firebase api key',
              firebaseMobileSdkAppId: 'firebase mobile app sdk id',
              firebaseStorageBucket: 'firebase storage key url',
              firebaseUrl: '',
              firebaseProjectNumber: 'firebase project number');
        }

- Note: All the above information can be found in google-services.json and info.plist file that has
  been already downloaded from Google firebase console.

If you have set FeedSDK.startScreen and want to override the SDK's default behaviour by receiving
all the data payload to the main app class, then you need to do add the below package into your
pubspec.yaml file (don't forget to call - 'flutter pub get')

        get: ^4.3.7

then add the GetMaterialApp widget as below sample:

        class MyApp extends StatelessWidget {
          const MyApp({Key? key}) : super(key: key);

          // This widget is the root of your application.
          @override
          Widget build(BuildContext context) {
            return GetMaterialApp(
              onGenerateRoute: (settings) {
                if (settings.name == FeedSDK.startScreen) {
                  final args = settings.arguments;
                  Logs.d('onGenerateRoute $args');
                }
              },
              title: 'Flutter Demo',
              theme: ThemeData(
                primarySwatch: Colors.blue,
              ),
              home: const MyHomePage(title: 'Flutter Demo Home Page'),
            );
          }
        }

You can read the data based on the keys available inside Constants class.

## How to read the notification data in your app?

When FeedSDK.startScreen = '#any text' is set, then the data is passed to the root widget of your
app, then you can read the data as below, which can be used for deeplinking or navigating through
your app based on the notification data:

      class MyApp extends StatelessWidget {
          const MyApp({Key? key}) : super(key: key);

          // This widget is the root of your application.
          @override
          Widget build(BuildContext context) {
            return GetMaterialApp(
              onGenerateRoute: (settings) {
                if (settings.name == FeedSDK.startScreen) {
                  final args = settings.arguments as List<Map<String, String>>;
                  var icon = args[0][Constants.icon];
                  var title = args[0][Constants.title];
                  var body = args[0][Constants.body];
                  var type = args[0][Constants.type];
                  Logs.d(icon! + title! + body! + type!);
                }
              },
              title: 'Flutter Demo',
              theme: ThemeData(
                primarySwatch: Colors.blue,
              ),
              home: const MyHomePage(title: 'Flutter Demo Home Page'),
            );
          }
        }

## Getting started (iOS)

Integrating the Cloud Messaging plugin on iOS & macOS devices requires additional setup before your
devices receive messages. There are also a number of prerequisites which are required to be able to
enable messaging:

- You must have an active
  Apple [Developer Account](https://idmsa.apple.com/IDMSWebAuth/signin?appIdKey=891bd3417a7776362562d2197f89480a8547b108fd934911bcbea0110d07f757&path=%2Faccount%2F&rv=1)
  .
- For iOS; you must have a physical iOS device to receive messages.
  - Firebase Cloud Messaging integrates with
    the [Apple Push Notification service (APNs)](https://developer.apple.com/notifications/),
    however APNs only works with real devices.

For configuring FCM on iOS devices, follow
the [steps mentioned in here](https://firebase.flutter.dev/docs/messaging/apple-integration/#configuring-your-app)

The most important part in order to make this library
work [is](https://firebase.flutter.dev/docs/messaging/apple-integration/#linking-apns-with-fcm)
